@@ -46,12 +46,12 @@
 
 KAMD_EXPORT_PLUGIN(sqliteplugin, StatsPlugin, "kactivitymanagerd-plugin-sqlite.json")
 
-StatsPlugin *StatsPlugin::s_instance = Q_NULLPTR;
+StatsPlugin *StatsPlugin::s_instance = nullptr;
 
 StatsPlugin::StatsPlugin(QObject *parent, const QVariantList &args)
     : Plugin(parent)
-    , m_activities(Q_NULLPTR)
-    , m_resources(Q_NULLPTR)
+    , m_activities(nullptr)
+    , m_resources(nullptr)
     , m_resourceLinking(new ResourceLinking(this))
 {
     Q_UNUSED(args);
@@ -155,13 +155,13 @@ void StatsPlugin::openResourceEvent(const QString &usedActivity,
 {
     Q_ASSERT_X(!initiatingAgent.isEmpty(),
                "StatsPlugin::openResourceEvent",
-               "Agent shoud not be empty");
+               "Agent should not be empty");
     Q_ASSERT_X(!usedActivity.isEmpty(),
                "StatsPlugin::openResourceEvent",
-               "Activity shoud not be empty");
+               "Activity should not be empty");
     Q_ASSERT_X(!targettedResource.isEmpty(),
                "StatsPlugin::openResourceEvent",
-               "Resource shoud not be empty");
+               "Resource should not be empty");
 
     detectResourceInfo(targettedResource);
 
@@ -187,13 +187,13 @@ void StatsPlugin::closeResourceEvent(const QString &usedActivity,
 {
     Q_ASSERT_X(!initiatingAgent.isEmpty(),
                "StatsPlugin::closeResourceEvent",
-               "Agent shoud not be empty");
+               "Agent should not be empty");
     Q_ASSERT_X(!usedActivity.isEmpty(),
                "StatsPlugin::closeResourceEvent",
-               "Activity shoud not be empty");
+               "Activity should not be empty");
     Q_ASSERT_X(!targettedResource.isEmpty(),
                "StatsPlugin::closeResourceEvent",
-               "Resource shoud not be empty");
+               "Resource should not be empty");
 
     Utils::prepare(*resourcesDatabase(), closeResourceEventQuery, QStringLiteral(
         "UPDATE ResourceEvent "
@@ -553,13 +553,13 @@ void StatsPlugin::DeleteStatsForResource(const QString &activity,
 {
     Q_ASSERT_X(!client.isEmpty(),
                "StatsPlugin::DeleteStatsForResource",
-               "Agent shoud not be empty");
+               "Agent should not be empty");
     Q_ASSERT_X(!activity.isEmpty(),
                "StatsPlugin::DeleteStatsForResource",
-               "Activity shoud not be empty");
+               "Activity should not be empty");
     Q_ASSERT_X(!resource.isEmpty(),
                "StatsPlugin::DeleteStatsForResource",
-               "Resource shoud not be empty");
+               "Resource should not be empty");
     Q_ASSERT_X(client != CURRENT_AGENT_TAG,
                "StatsPlugin::DeleteStatsForResource",
                "We can not handle CURRENT_AGENT_TAG here");
